[Libreoffice-commits] core.git: svx/source sw/CppunitTest_sw_layoutwriter.mk sw/CppunitTest_sw_uiwriter.mk sw/CppunitTest_sw_unowriter.mk

Andrea Gelmini (via logerrit) logerrit at kemper.freedesktop.org
Tue Aug 13 07:01:02 UTC 2019


 svx/source/unodraw/unoshap2.cxx   |    2 +-
 svx/source/unodraw/unoshape.cxx   |    8 ++++----
 svx/source/xml/xmlgrhlp.cxx       |    4 ++--
 svx/source/xoutdev/_xpoly.cxx     |   10 +++++-----
 sw/CppunitTest_sw_layoutwriter.mk |    2 +-
 sw/CppunitTest_sw_uiwriter.mk     |    2 +-
 sw/CppunitTest_sw_unowriter.mk    |    2 +-
 7 files changed, 15 insertions(+), 15 deletions(-)

New commits:
commit 5c8d191d3f735173c8234b62deabbdfc40cc1e2f
Author:     Andrea Gelmini <andrea.gelmini at gelma.net>
AuthorDate: Tue Aug 13 08:49:31 2019 +0200
Commit:     Julien Nabet <serval2412 at yahoo.fr>
CommitDate: Tue Aug 13 09:00:28 2019 +0200

    Fix typos
    
    Change-Id: If99059383039e65aacfc55baec660eb6fde47032
    Reviewed-on: https://gerrit.libreoffice.org/77376
    Reviewed-by: Julien Nabet <serval2412 at yahoo.fr>
    Tested-by: Julien Nabet <serval2412 at yahoo.fr>

diff --git a/svx/source/unodraw/unoshap2.cxx b/svx/source/unodraw/unoshap2.cxx
index 3589c088ac36..97935d68af4f 100644
--- a/svx/source/unodraw/unoshap2.cxx
+++ b/svx/source/unodraw/unoshap2.cxx
@@ -207,7 +207,7 @@ void SvxShapeGroup::addUnoShape( const uno::Reference< drawing::XShape >& xShape
 
     GetSdrObject()->GetSubList()->InsertObject(pSdrShape, nPos);
     // TTTT Was created using mpModel in CreateSdrObject_ above
-    // TTTT may be good to add a assertion here for the future
+    // TTTT may be good to add an assertion here for the future
     // pSdrShape->SetModel(GetSdrObject()->GetModel());
 
     // #85922# It makes no sense to set the layer asked
diff --git a/svx/source/xml/xmlgrhlp.cxx b/svx/source/xml/xmlgrhlp.cxx
index edbfb16c41f8..0490a7008132 100644
--- a/svx/source/xml/xmlgrhlp.cxx
+++ b/svx/source/xml/xmlgrhlp.cxx
@@ -691,7 +691,7 @@ OUString SvXMLGraphicHelper::implSaveGraphic(css::uno::Reference<css::graphic::X
             }
             else if (aGraphicObject.GetType() == GraphicType::GdiMetafile)
             {
-                // SJ: first check if this metafile is just a eps file, then we will store the eps instead of svm
+                // SJ: first check if this metafile is just an eps file, then we will store the eps instead of svm
                 GDIMetaFile& rMetafile(const_cast<GDIMetaFile&>(aGraphic.GetGDIMetaFile()));
 
                 if (ImplCheckForEPS(rMetafile))
@@ -811,7 +811,7 @@ OUString SvXMLGraphicHelper::implSaveGraphic(css::uno::Reference<css::graphic::X
                     pStream->SetCompressMode(SvStreamCompressFlags::ZBITMAP);
                     rOutSavedMimeType = comphelper::GraphicMimeTypeHelper::GetMimeTypeForExtension("svm");
 
-                    // SJ: first check if this metafile is just a eps file, then we will store the eps instead of svm
+                    // SJ: first check if this metafile is just an eps file, then we will store the eps instead of svm
                     GDIMetaFile& rMtf(const_cast<GDIMetaFile&>(aGraphic.GetGDIMetaFile()));
                     const MetaCommentAction* pComment = ImplCheckForEPS(rMtf);
                     if (pComment)
diff --git a/svx/source/xoutdev/_xpoly.cxx b/svx/source/xoutdev/_xpoly.cxx
index 74980ecdc994..d937a54e8710 100644
--- a/svx/source/xoutdev/_xpoly.cxx
+++ b/svx/source/xoutdev/_xpoly.cxx
@@ -152,7 +152,7 @@ void ImpXPolygon::InsertSpace( sal_uInt16 nPos, sal_uInt16 nCount )
     if ( nPos > nPoints )
         nPos = nPoints;
 
-    // if the polygon is too small than enlarge it
+    // if the polygon is too small then enlarge it
     if( (nPoints + nCount) > nSize )
         Resize( nPoints + nCount );
 
@@ -283,7 +283,7 @@ XPolygon::XPolygon(const tools::Rectangle& rRect, long nRx, long nRy)
     pImpXPolygon->nPoints = nPos + 1;
 }
 
-/// create a ellipse (curve) as Bézier polygon
+/// create an ellipse (curve) as Bézier polygon
 XPolygon::XPolygon(const Point& rCenter, long nRx, long nRy,
                    sal_uInt16 nStartAngle, sal_uInt16 nEndAngle, bool bClose)
     : pImpXPolygon( 17 )
@@ -311,7 +311,7 @@ XPolygon::XPolygon(const Point& rCenter, long nRx, long nRy,
 
     } while ( !bLoopEnd );
 
-    // if not a full circle than connect edges with center point if necessary
+    // if not a full circle then connect edges with center point if necessary
     if ( !bFull && bClose )
         pImpXPolygon->pPointAry[++nPos] = rCenter;
 
@@ -619,7 +619,7 @@ bool XPolygon::CheckAngles(sal_uInt16& nStart, sal_uInt16 nEnd, sal_uInt16& nA1,
  */
 void XPolygon::CalcSmoothJoin(sal_uInt16 nCenter, sal_uInt16 nDrag, sal_uInt16 nPnt)
 {
-    // If nPoint is no control point, i.e. cannot be moved, than
+    // If nPoint is no control point, i.e. cannot be moved, then
     // move nDrag instead on the line between nCenter and nPnt
     if ( !IsControl(nPnt) )
     {
@@ -787,7 +787,7 @@ void XPolygon::Distort(const tools::Rectangle& rRefRect,
     long    X1, X2, X3, X4;
     long    Y1, Y2, Y3, Y4;
     DBG_ASSERT(rDistortedRect.pImpXPolygon->nPoints >= 4,
-               "Distort: rectangle to small");
+               "Distort: rectangle too small");
 
     X1 = rDistortedRect[0].X();
     Y1 = rDistortedRect[0].Y();
diff --git a/sw/CppunitTest_sw_layoutwriter.mk b/sw/CppunitTest_sw_layoutwriter.mk
index aaddcffb4d8a..763c531e582e 100644
--- a/sw/CppunitTest_sw_layoutwriter.mk
+++ b/sw/CppunitTest_sw_layoutwriter.mk
@@ -15,7 +15,7 @@ $(eval $(call gb_CppunitTest_add_exception_objects,sw_layoutwriter, \
     sw/qa/extras/layout/layout \
 ))
 
-# note: this links msword only for the reason to have a order dependency,
+# note: this links msword only for the reason to have an order dependency,
 # because "make sw.check" will not see the dependency through services.rdb
 $(eval $(call gb_CppunitTest_use_libraries,sw_layoutwriter, \
     comphelper \
diff --git a/sw/CppunitTest_sw_uiwriter.mk b/sw/CppunitTest_sw_uiwriter.mk
index e6867b790b9d..c649bd1ba12e 100644
--- a/sw/CppunitTest_sw_uiwriter.mk
+++ b/sw/CppunitTest_sw_uiwriter.mk
@@ -16,7 +16,7 @@ $(eval $(call gb_CppunitTest_add_exception_objects,sw_uiwriter, \
     sw/qa/extras/uiwriter/uiwriter2 \
 ))
 
-# note: this links msword only for the reason to have a order dependency,
+# note: this links msword only for the reason to have an order dependency,
 # because "make sw.check" will not see the dependency through services.rdb
 $(eval $(call gb_CppunitTest_use_libraries,sw_uiwriter, \
     comphelper \
diff --git a/sw/CppunitTest_sw_unowriter.mk b/sw/CppunitTest_sw_unowriter.mk
index 32e7ff06a0d5..f9d5cac9d2b8 100644
--- a/sw/CppunitTest_sw_unowriter.mk
+++ b/sw/CppunitTest_sw_unowriter.mk
@@ -15,7 +15,7 @@ $(eval $(call gb_CppunitTest_add_exception_objects,sw_unowriter, \
     sw/qa/extras/unowriter/unowriter \
 ))
 
-# note: this links msword only for the reason to have a order dependency,
+# note: this links msword only for the reason to have an order dependency,
 # because "make sw.check" will not see the dependency through services.rdb
 $(eval $(call gb_CppunitTest_use_libraries,sw_unowriter, \
     comphelper \


More information about the Libreoffice-commits mailing list
diff --git a/svx/source/unodraw/unoshape.cxx b/svx/source/unodraw/unoshape.cxx
index da9881ac3a64..d7f665bc9253 100644
--- a/svx/source/unodraw/unoshape.cxx
+++ b/svx/source/unodraw/unoshape.cxx
@@ -1946,7 +1946,7 @@ uno::Any SvxShape::GetAnyForItem( SfxItemSet const & aSet, const SfxItemProperty
     }
     default:
     {
-        // get value form ItemSet
+        // get value from ItemSet
         aAny = SvxItemPropertySet_getPropertyValue( pMap, aSet );
 
         if( pMap->aType != aAny.getValueType() )
@@ -2012,7 +2012,7 @@ beans::PropertyState SvxShape::_getPropertyState( const OUString& PropertyName )
             break;
         }
 
-        // if a item is set, this doesn't mean we want it :)
+        // if an item is set, this doesn't mean we want it :)
         if( beans::PropertyState_DIRECT_VALUE == eState )
         {
             switch( pMap->nWID )
@@ -3803,9 +3803,9 @@ sal_Int16 SAL_CALL SvxShape::resetActionLocks(  )
 }
 
 
 /** since polygon shapes can change theire kind during editing, we have
     to recheck it here.
-    Circle shapes also change theire kind, but theire all treated equal
+    Circle shapes also change their kind, but they are all treated equal
     so no update is necessary.
 */
 void SvxShape::updateShapeKind()
@@ -3803,9 +3803,9 @@ sal_Int16 SAL_CALL SvxShape::resetActionLocks(  )
 
 
-/** since polygon shapes can change theire kind during editing, we have
+/** since polygon shapes can change their kind during editing, we have
     to recheck it here.